#!/usr/bin/python
# -*- coding: utf-8 -*-
# version 1.0.0
from pprint import pprint
import base64
import json
import requests

# define output of the REST request as json
# and other parameterized values used below
loginHeaders = {'Content-Type': 'application/x-www-form-urlencoded'}
hdrs = {'Accept': 'application/json'}
loginParams = {'username': 'USERNAMEHERE', 'password': 'PASSWORDHERE'}

hiveBaseURL = 'https://bumblebee.hive.swarm.space/hive'
loginURL = hiveBaseURL + '/login'
getMessageURL = hiveBaseURL + '/api/v1/messages'
ackMessageURL = hiveBaseURL + '/api/v1/messages/rxack/{}'

# dont do the ACK
doACK = False

# create a session
with requests.Session() as s:
    # log in to get the JSESSIONID cookie
    res = s.post(loginURL, data=loginParams, headers=loginHeaders)
    #print(res.url)

if res.status_code != 200:
    print("Invalid username or password; please use a valid username and password in loginParams.")
    exit(1)

# print out the JSESSIONID cookie
#print(s.cookies)

# let the session manage the cookie and get the output for the given appID
# only pull the last 10 items that have not been ACK'd
res = s.get(getMessageURL, headers=hdrs, params={'count': 10, 'status': 0})
# print(res)

messages = res.json()

# print out the prettied version of the JSON records for unacknowledge data records in the hive
print(json.dumps(messages, indent=4))

# for all the items in the json returned (limited to 10 above)
for item in messages:
    # if there is a 'data' keypair, output the data portion converting it from base64 to ascii - assumes not binary
    if (item['data']):
        print('Decoded Message: ' + base64.b64decode(item['data']).decode('ascii') + '\n')

# example ACK the first item returned ONLY!
if (doACK):
    # ack first available
    # issue the get to ack the 0th (or first returned element)
    # note you should check the initial return to make sure there are packets available before you ack one
    res1 = s.post(ackMessageURL.format(messages[0]['packetId']), headers=hdrs)
    # print(res)

    # print out the response from the ACK request
    pprint(res1.json())
